applyVelocityCommand {#master}
-----------

Important Changes
-----------------

### YARP_dev

* `applyVelocityCommand()` method moved from `yarp::dev::Nav2D::INavigation2DTargetActions` to
   new interface `yarp::dev::Nav2D::INavigation2DVelocityActions`
